@@ -291,6 +291,10 @@ void Mainwin::handle_callb (int k, X_window *W, XEvent *E)
             case B_TRM1:
                 edit_trim1 (X->button == Button3);
  	        break; 
+
+            case B_FADE:
+                edit_fade (X->button == Button3);
+ 	        break; 
 	    }
 	}
 	break;
@@ -932,6 +936,7 @@ void Mainwin::edit_init ()
 {
     _offs = 0;
     _gain = 1.0f;
+    _slope = 0.0f;
     _ind0  = 0;
     _ind1  = _data1->n_fram () - 1;
     _ttref->set_text ("0.0");
@@ -940,6 +945,8 @@ void Mainwin::edit_init ()
     _ttrm01->set_text ("--");
     _ttrm10->set_text ("--");
     _ttrm11->set_text ("--");
+    _ttfade->set_text ("--");
+    _tslope->set_text ("0.0");
     _btref->set_stat (0);
     _bgain->set_stat (0);
     _btrim0->set_stat (0);
@@ -958,6 +965,7 @@ int Mainwin::edit_prep (M_calc_edit *M)
     M->_gain = _gain;
     M->_ind0 = _ind0;
     M->_ind1 = _ind1;
+    M->_slope = 0;
     if (_btrim0->stat ())
     {
 	M->_trm00 = _trm00;
@@ -970,6 +978,11 @@ int Mainwin::edit_prep (M_calc_edit *M)
 	M->_trm11 = _trm11;
     }
     else M->_trm10 = M->_trm11 = 0;
+    if (_bfade->stat ())
+    {
+	M->_tfade = _tfade;
+	M->_slope = _slope;
+    }
     return 0;
 }
 
@@ -1113,7 +1126,7 @@ void Mainwin::edit_gain (bool undo, bool norm)
 	i = _editwin->get_currmark ();
         if (i < 0) return;
         k = _editwin->get_markpos (i);
-        r = _data1->rate_n () / (_data1->rate_d () * 200); 
+        r = _data1->rate_n () / (_data1->rate_d () * 100); 
         s = _data1->n_fram () - 1; 
         c = _data1->n_chan ();
         i0 = k - r;
@@ -1131,8 +1144,8 @@ void Mainwin::edit_gain (bool undo, bool norm)
                 p = _data1->data (j);
                 for (i = i0; i <= i1; i++)
 	        {
-		    v = p [c * i] * 0.5f * (1.0f + cosf (M_PI * (i - k) / r));
-		    u += v * v;
+		    v = p [c * i];
+		    u += v * v * 0.5f * (1.0f + cosf (M_PI * (i - k) / r));
 		}
 	    }
 	}  
@@ -1217,6 +1230,37 @@ void Mainwin::edit_trim1 (bool undo)
 }
 
 
+void Mainwin::edit_fade (bool undo)
+{
+    int   i, k;
+    float v;
+
+    if (undo)
+    {
+	if (_bfade->stat ())
+	{
+	    _bfade->set_stat (0);
+	    _ttfade->set_text ("--");
+	}
+        else return;
+    }
+    else
+    {
+	i = _editwin->get_currmark ();
+        if (i < 0) return;
+        k = _editwin->get_markpos (i);
+	if (k < _ind0) return;
+	if (k > _ind1) return;
+	if (sscanf (_tslope->text (), "%f", &v) != 1) return;
+	_slope = v;
+	_tfade = k;
+        _bfade->set_stat (2);
+	ptime (_tfade, _ttfade);
+    }
+    edit_calc_one (0);
+}
+
+
 void Mainwin::sint_init ()
 {
     _subs = (U32)(_data1->drate() / 1000);
@@ -1388,6 +1432,12 @@ void Mainwin::makewin (void)
     _ttrm11->x_map ();
     _btrim1 = new X_tbutton (W, this, &Bst0, 363, 39, "Trim end",   0, B_TRM1);
     _btrim1->x_map ();
+    _ttfade = new X_textip (W, 0,     &Tst1, 460, 20, 80, 18, 1023, 0);
+    _ttfade->x_map ();
+    _tslope = new X_textip (W, this,  &Tst1, 541, 20, 80, 18, 1023, 0);
+    _tslope->x_map ();
+    _bfade = new X_tbutton (W, this, &Bst0,  623, 20, "Fade out", 0, B_FADE);
+    _bfade->x_map ();
 
     _ifwsint = W = new X_window (this, 0, 0, 1200, TMAR, XftColors.main_bg->pixel);
     (new X_tbutton (W, this, &Bst0,  0, 0, "Back", 0, B_CANC))->x_map ();
